@@ -16,7 +16,7 @@ def main():
         for g in res:
             print("-" * 20)
             for l in g:
-                print(l)
+                print(l, l.title)
             print()
 
 if __name__ == "__main__":
